com.togethersoft.openapi.util.enum
Class Diagram enum

Class Summary
AbstractButtonEnumerationEnumeration of Swing's AbstractButtons.
AbstractButtonEnumerationAdapterMinimal implementation of enumeration of AbstractButtons .
ArrayEnumerationPresents array of Objects as an enumeration.
CompositeEnumerationRepresents enumeration of enumerations.
DoubleEnumerationPresents two Objects as an enumeration.
EmptyEnumerationThis class presents always empty enumeration.
EnumerationCopyPresents enumeration on the base of existing enumeration.
FilterEnumerationPresents enumeration with filter which is a specified unary operation.
KeyStrokeEnumerationEnumeration of KeyStrokes.
KeyStrokeEnumerationAdapterContents minimal implementation to work with enumeration of KeyStrokes.
LightEnumerationPresents light version of enumeration.
LightEnumerationAdapterAdapts light enumeration to stadard enumeration.
OrderedDiffEnumerationRepresents enumeration constructed from two others.
OrderedMergerEnumerationRepresents enumeration which built from two others.
PointEnumerationEnumeration of Points.
PointEnumerationAdapterAdaptes existing enumeration to the enumeration of AWT Points.
SequenceEnumerationHandles two or three enumerations as one.
SingleEnumerationPresents enumeration contains only one element as an Object.
StringEnumerationEnumeration of Strings.
StringEnumerationAdapterMinimal implementation enumeration of a Strings.