| ||||||||||
| PREV DIAGRAM NEXT DIAGRAM | FRAMES NO FRAMES | |||||||||
| Class Summary | |
| AbstractButtonEnumeration | Enumeration of Swing's AbstractButtons. |
| AbstractButtonEnumerationAdapter | Minimal implementation of enumeration of AbstractButtons . |
| ArrayEnumeration | Presents array of Objects as an enumeration. |
| CompositeEnumeration | Represents enumeration of enumerations. |
| DoubleEnumeration | Presents two Objects as an enumeration. |
| EmptyEnumeration | This class presents always empty enumeration. |
| EnumerationCopy | Presents enumeration on the base of existing enumeration. |
| FilterEnumeration | Presents enumeration with filter which is a specified unary operation. |
| KeyStrokeEnumeration | Enumeration of KeyStrokes. |
| KeyStrokeEnumerationAdapter | Contents minimal implementation to work with enumeration of KeyStrokes. |
| LightEnumeration | Presents light version of enumeration. |
| LightEnumerationAdapter | Adapts light enumeration to stadard enumeration. |
| OrderedDiffEnumeration | Represents enumeration constructed from two others. |
| OrderedMergerEnumeration | Represents enumeration which built from two others. |
| PointEnumeration | Enumeration of Points. |
| PointEnumerationAdapter | Adaptes existing enumeration to the enumeration of AWT Points. |
| SequenceEnumeration | Handles two or three enumerations as one. |
| SingleEnumeration | Presents enumeration contains only one element as an Object. |
| StringEnumeration | Enumeration of Strings. |
| StringEnumerationAdapter | Minimal implementation enumeration of a Strings. |
| ||||||||||
| PREV DIAGRAM NEXT DIAGRAM | FRAMES NO FRAMES | |||||||||